# See https://docs.fedoraproject.org/en-US/packaging-guidelines/#_compiler_macros
%global toolchain clang

%global nanobind_giturl https://github.com/wjakob/nanobind
%global nanobind_src_dir nanobind-%{version}

# The combination of an arched package with only noarch binary packages makes
# it easier for us to detect arch-dependent test failures, since the tests will
# always be run on every platform.
# Since the package still contains no compiled machine code, we still have no
# debuginfo.
%global debug_package %{nil}

Name:           python-nanobind
Version:        2.5.0
Release:        %mkrel 2
Summary:        Tiny and efficient C++/Python bindings
Group:          Development/Python
License:        BSD-3-Clause
URL:            https://nanobind.readthedocs.org/
VCS:            git:%{nanobind_giturl}.git
Source0:        %{nanobind_giturl}/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         nanobind-linking.patch

BuildRequires:  clang
BuildRequires:  cmake
BuildRequires:  eigen3-devel
BuildRequires:  librsvg2
BuildRequires:  ninja-build
BuildRequires:  python3-devel
BuildRequires:  python3-pytest
BuildRequires:  robin-map-devel >= 1.3.0

%description
nanobind is a small binding library that exposes C++ types
in Python and vice versa. It is reminiscent of Boost.Python
and pybind11 and uses near-identical syntax.
In contrast to these existing tools, nanobind is more
efficient: bindings compile in a shorter amount of time,
produce smaller binaries, and have better runtime performance.

%package -n     python3-nanobind
Summary:        Tiny and efficient C++/Python bindings
Group:          Development/Python
BuildArch:      noarch

%description -n python3-nanobind
nanobind is a small binding library that exposes C++ types
in Python and vice versa. It is reminiscent of Boost.Python
and pybind11 and uses near-identical syntax.
In contrast to these existing tools, nanobind is more
efficient: bindings compile in a shorter amount of time,
produce smaller binaries, and have better runtime performance.


%package -n     python3-nanobind-devel
Summary:        Development files for nanobind
BuildArch:      noarch
Requires:       python3-nanobind = %{version}-%{release}
# Anyone who uses the devel package will need robin-map-devel package,
# which is why this is a runtime dependency here.
Requires:       robin-map-devel >= 1.3.0

%description -n python3-nanobind-devel
Development files for nanobind.


%prep
%autosetup -p1 -n %{nanobind_src_dir}

%py3_shebang_fix src/stubgen.py


%generate_buildrequires
%pyproject_buildrequires


%build
# See https://github.com/scikit-build/scikit-build-core?tab=readme-ov-file#configuration
%{pyproject_wheel: \
-C"build-dir=%{_vpath_builddir}" \
-C"cmake.define.NB_USE_SUBMODULE_DEPS=false" \
-C"cmake.build-type=RelWithDebInfo" \
-C"cmake.define.NB_TEST_SHARED_BUILD=false" \
-C"cmake.define.NB_TEST=true" \
-C"build.verbose=true" \
}

%install
%pyproject_install
%pyproject_save_files nanobind


%check
%pyproject_check_import
# Test files are not installed, hence we need
# to enter the build directory manually.
pushd %{_vpath_builddir}
%pytest
popd


%files -n python3-nanobind -f %{pyproject_files}
%license LICENSE
%exclude %{python3_sitelib}/nanobind/include
%exclude %{python3_sitelib}/nanobind/src
%exclude %{python3_sitelib}/nanobind/cmake
%pycached %exclude %{python3_sitelib}/nanobind/stubgen.py
# Exclude not needed files
%exclude %{python3_sitelib}/nanobind/cmake/darwin-ld-cpython.sym
%exclude %{python3_sitelib}/nanobind/cmake/darwin-ld-pypy.sym


%files -n python3-nanobind-devel
%{python3_sitelib}/nanobind/include/
%{python3_sitelib}/nanobind/src/
%{python3_sitelib}/nanobind/cmake/
%pycached %{python3_sitelib}/nanobind/stubgen.py


%changelog
* Sun Feb 02 2025 daviddavid <daviddavid> 2.5.0-2.mga10
+ Revision: 2144846
- fix linking issue

* Sun Feb 02 2025 daviddavid <daviddavid> 2.5.0-1.mga10
+ Revision: 2144618
- initial package python-nanobind (needed for python-opencl)

